@@ -9,6 +9,7 @@ use Carp qw(cluck croak);
 use Regexp::Common 'RE_ALL';
 use PEF::Front::Captcha;
 use PEF::Front::Config;
+use PEF::Front::Model;
 use Sub::Name;
 use base 'Exporter';
 our @EXPORT = qw{
@@ -747,38 +748,7 @@ sub load_validation_rules {
 		for (keys %$new_rules) {
 			$model_cache{$method}{$_} = $new_rules->{$_} if $_ ne 'code';
 		}
-		my $model;
-		my $model_sub;
-		my $cfg_model_sub;
-		if ($new_rules->{model} && !ref($new_rules->{model}) && $new_rules->{model} =~ /^\w+::/) {
-			if ($new_rules->{model} =~ /^PEF::Front/) {
-				$model = $new_rules->{model};
-			} else {
-				$model = cfg_app_namespace . "Local::$new_rules->{model}";
-			}
-			my $class = substr($model, 0, rindex($model, "::"));
-			my $can = substr($model, rindex($model, "::") + 2);
-			eval "use $class";
-			$@ = "$class must contain $can function" if not $@ and not $class->can($can);
-			croak {
-				result      => 'INTERR',
-				answer      => 'Validator $1 loading model error: $2',
-				answer_args => [$method, "$@"],
-				}
-				if $@;
-			$model_sub = "sub { eval { $model(\@_) } }";
-		} else {
-			$model = $new_rules->{model} || 'rpc_site';
-			$cfg_model_sub = eval {cfg_model_rpc($model)};
-			$@ = "cfg_model_rpc('$model') must return dode reference" if ref $cfg_model_sub ne 'CODE';
-			croak {
-				result      => 'INTERR',
-				answer      => 'Validator $1 loading model error: $2',
-				answer_args => [$method, "$@"],
-				}
-				if $@;
-			$model_sub = "sub { eval { \$cfg_model_sub->(\@_) } }";
-		}
+		my ($model, $model_sub) = PEF::Front::Model::make_model_call($method, $new_rules->{model});
 		$model_cache{$method}{model}     = $model;
 		$model_cache{$method}{model_sub} = eval $model_sub;
 		if (exists $new_rules->{result}) {
